Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(219)

Unified Diff: remoting/host/client_session.h

Issue 9646013: Add the plumbing that will carry a clipboard item from a chromoting client to a host. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix remoting_simple_host. Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/chromoting_host_unittest.cc ('k') | remoting/host/client_session.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/client_session.h
diff --git a/remoting/host/client_session.h b/remoting/host/client_session.h
index 31ac0793dcf81b0cabad117c7bb91d8a37800aa5..6103c0842e3b20b6f0eae6c8bc8d03fab18bde36 100644
--- a/remoting/host/client_session.h
+++ b/remoting/host/client_session.h
@@ -10,9 +10,10 @@
#include "base/time.h"
#include "base/threading/non_thread_safe.h"
+#include "remoting/protocol/clipboard_stub.h"
#include "remoting/protocol/connection_to_client.h"
+#include "remoting/protocol/host_event_stub.h"
#include "remoting/protocol/host_stub.h"
-#include "remoting/protocol/input_stub.h"
#include "third_party/skia/include/core/SkPoint.h"
namespace remoting {
@@ -21,8 +22,8 @@ class Capturer;
// A ClientSession keeps a reference to a connection to a client, and maintains
// per-client state.
-class ClientSession : public protocol::HostStub,
- public protocol::InputStub,
+class ClientSession : public protocol::HostEventStub,
+ public protocol::HostStub,
public protocol::ConnectionToClient::EventHandler,
public base::NonThreadSafe {
public:
@@ -57,13 +58,17 @@ class ClientSession : public protocol::HostStub,
};
// Takes ownership of |connection|. Does not take ownership of
- // |event_handler|, |input_stub| or |capturer|.
+ // |event_handler|, |host_event_stub|, or |capturer|.
ClientSession(EventHandler* event_handler,
protocol::ConnectionToClient* connection,
- protocol::InputStub* input_stub,
+ protocol::HostEventStub* host_event_stub,
Capturer* capturer);
virtual ~ClientSession();
+ // protocol::ClipboardStub interface.
+ virtual void InjectClipboardEvent(
+ const protocol::ClipboardEvent& event) OVERRIDE;
+
// protocol::InputStub interface.
virtual void InjectKeyEvent(const protocol::KeyEvent& event) OVERRIDE;
virtual void InjectMouseEvent(const protocol::MouseEvent& event) OVERRIDE;
@@ -130,8 +135,8 @@ class ClientSession : public protocol::HostStub,
std::string client_jid_;
- // The input stub to which this object delegates.
- protocol::InputStub* input_stub_;
+ // The host event stub to which this object delegates.
+ protocol::HostEventStub* host_event_stub_;
// Capturer, used to determine current screen size for ensuring injected
// mouse events fall within the screen area.
« no previous file with comments | « remoting/host/chromoting_host_unittest.cc ('k') | remoting/host/client_session.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698